Add GFX908 specific changes to HIP (#1229)

* Add GFX908 specific for HIP

* Fix missing __halfTest in hipTestNativeHalf
This commit is contained in:
Aaron Enye Shi
2019-07-24 03:51:17 -04:00
committed by Maneesh Gupta
parent 7feda764b6
commit 8c82f9db77
8 changed files with 30 additions and 7 deletions
@@ -29,7 +29,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
#include "test_common.h"
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
__global__ void kernel_abs_int64(long long *input, long long *output) {
int tx = threadIdx.x;
+1 -1
View File
@@ -28,7 +28,7 @@ THE SOFTWARE.
#include "test_common.h"
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
__global__
void __halfMath(bool* result, __half a) {
@@ -32,7 +32,7 @@ THE SOFTWARE.
using namespace std;
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
__global__
void __halfTest(bool* result, __half a) {